**************************************************************************
*This file contains the code to reproduce Figure 1 in Ubfal (2024)
*What works in supporting women-led businesses.
* Input: Data downloaded from the World Bank intranet, Enterprise Surveys
*File name: "New_Comprehensive_March_1_2024.dta"
*Output: Figure1. 

clear
version 16
cd ""

use New_Comprehensive_March_1_2024.dta

*Sample weights provided by enterprise surveys
svyset idstd [pweight=wt], strata(strata) singleunit(scaled)
 

***********************************************
*Definition of women-led firms 
***********************************************
 *Definition Adopted: at least 50% of women in ownership or top female manager  
 *To construct this variable we combine information from 4 variables: 
			*1) b4: any female among owners, 
			*2) b4a: % of firm owned by females,
			*3) b4_cat: female ownership categories
			*4) b7a: female top manager
 
*Any female owner
 gen female_owner=b4==1 if b4>0 & b4<.
label var female_owner "At least 1 female owner"
 *Replace with "1" when reported share of female ownership is greater than 0, but any female owner variable was missing
replace female_owner=1 if b4a>0 & b4a<.

*More than 50% female ownership
gen female_50more=b4a>50 if b4a<.
replace female_50more=0 if female_owner==0
replace female_50more=1 if b4a_cat>=3 & b4a_cat<5 
label var female_50more "More than 50 percent female owned"
replace female_owner=1 if female_50more==1 & female_owner==.

*Female top manager
gen female_topmanager=b7a==1 if b7a>0 & b7a<.
label var female_topmanager "Top Manager is Female"


*Definition adopted
gen female_led=(female_50more==1 | female_topmanager==1) if (female_50more!=. | female_topmanager!=.)



******************************************************************************
*Different Definitions of women-led firms used for Footnote 3 in the paper
******************************************************************************
 *Definition 1: Adopted - more than 50% of women in ownership or woman manager
 label var female_led "Definition 1"
 *Definition 2: top manager is a woman
 label var female_topmanager "Defition 2"
 *Definition 3: more than 50% women in ownership
 label var female_50more "Definition 3"
 *Definition 4: at least 1 woman owner AND woman is top manager
 
gen female_owned=.
replace female_owned=1 if female_topmanager==1 & female_owner==1
replace female_owned=0 if female_topmanager==0 | female_owner==0
label var female_owned "At least one female owner and female top manager"
label var female_owned "Definition 4"
 
 *Definition 5: At least 20% of women in ownership and female top manager
 gen female_closetoifc=0
replace female_closetoifc=1 if b4a>=20 & b4a<. & female_topmanager==1
label var female_closetoifc "Definition 5"
 
 *Definition 6: at least 1 female owner 
label var female_owner "Definition 6"

******************************************
*Sample selection for graph
******************************************
 *Keep only most recent survey for each country
  keep if sample==1

*Drop firms that do not report gender of owners or manager
drop if female_led==.

*Size categories based on sample frame
  gen small=(size==1) if size!=.
  gen mid=(size==2) if size!=.
  gen large=(size==3) if size!=.
 
 gen small_female=(female_led==1) if small==1
 gen mid_female=(female_led==1 ) if mid==1
 gen large_female=(female_led==1 ) if large==1
 
****************************************** 
*Collapsing using survey weights
******************************************
 collapse small mid large female_led small_female mid_female large_female female_owner female_topmanager female_owned  female_50more female_closetoifc  [pw=wt], by(country region) 
 
  *Drop countries where no woman-led firm was interviewed (reported as missing in Enterprise survey page)
  drop if female_led==0
  
  *Drop two countries where no small or medium firms were interviewed
 drop if mid_female==. | large_female==. 
 
 *Drop Nepal (women were oversampled using a different sampling strategy)
 drop if country=="Nepal2013"
 

 sum female_led
 dis "world share"=r(mean)
 
 sum female_topmanager
 dis "Definition 2"=r(mean)
 
  sum female_50more
 dis "Definition 3"=r(mean)
 
  sum female_owned
 dis "Definition 4"=r(mean)
 
  sum female_closetoifc
 dis "Definition 5"=r(mean)
 
   sum female_owner
 dis "Definition 6"=r(mean)
 
 

*Adding world to the regions 
 set obs 155
 replace region=0 in 155
 label define region 0 World, add
 sum small_female 
 replace small_female=r(mean) in 155
  sum mid_female 
 replace mid_female=r(mean) in 155
  sum large_female 
 replace large_female=r(mean) in 155
 
 foreach var of varlist small_female mid_female large_female {
 	replace `var'=100*`var'
 }
 
 
 *Final Graph in black and white
 graph hbar small_female mid_female large_female, over(region)  title("") ytitle(Percentage of firms led by women in the region by size of firm) ylabel(0 5 10 15 20 25 30 35 40) graphregion(fcolor(white)) blabel(total, format (%9.0f)) legend( rows(2) label(1 "Small (5-19 employees)") label(2 "Medium (20-99 employees)") label(3 "Large (>=100 employees)")) legend(cols(3)) yline(22, lwidth(thin) lcolor(red)) text(29 20 "World Aggregate = 22%")   bar(1,color(gs12)) bar(2,color (gs8))  bar(3,color(gs4)) scheme(s2color)

 graph export figure1_note_data2024.pdf, replace
 graph export figure1_note_data2024.png, replace
 

 

 


